@@ -24,14 +24,14 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 my $myclass;
 BEGIN {
     $myclass = __PACKAGE__;
-    $VERSION = '0.85';
+    $VERSION = '0.87';
 }
 sub Version () { "$myclass v$VERSION" }
 
 use AutoLoader;
 #use Exporter ();	# we inherit what we need here from Net::Gen
 use Net::Inet 0.85;
-use Net::Gen 0.85;
+use Net::Gen 0.87;
 use Socket qw(!/^[a-z]/ !SOMAXCONN);
 
 BEGIN {
@@ -78,7 +78,8 @@ BEGIN {
     local ($^W) = 0;		# prevent sub redefined warnings
     no strict 'refs';		# so we can do the defined() checks
     for $name (@EXPORT, @EXPORT_OK) {
-	eval "sub $name () ;" unless defined(&$name);
+	# declare alone is not enough--need reference to silence -w
+	eval "sub $name (); \&$name;" unless defined(&$name);
     }
 }
 
